Rename xdr to xdg Signed-off-by: Sven Strickroth <email@cs-ware.de>
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151
diff --git a/src/config.c b/src/config.c
index d8e5475..b89c16b 100644
--- a/src/config.c
+++ b/src/config.c
@@ -454,7 +454,7 @@ int git_config_find_global_r(git_buf *path)
return error;
}
-int git_config_find_xdr_r(git_buf *path)
+int git_config_find_xdg_r(git_buf *path)
{
int error = git_futils_find_global_file(path, GIT_CONFIG_FILENAME_ALT);
@@ -483,10 +483,10 @@ int git_config_find_global(char *global_config_path, size_t length)
return 0;
}
-int git_config_find_xdr(char *xdr_config_path, size_t length)
+int git_config_find_xdg(char *xdg_config_path, size_t length)
{
git_buf path = GIT_BUF_INIT;
- int ret = git_config_find_xdr_r(&path);
+ int ret = git_config_find_xdg_r(&path);
if (ret < 0) {
git_buf_free(&path);
@@ -500,7 +500,7 @@ int git_config_find_xdr(char *xdr_config_path, size_t length)
return -1;
}
- git_buf_copy_cstr(xdr_config_path, length, &path);
+ git_buf_copy_cstr(xdg_config_path, length, &path);
git_buf_free(&path);
return 0;
}
@@ -543,7 +543,7 @@ int git_config_open_default(git_config **out)
if (!error && !git_config_find_global_r(&buf))
error = git_config_add_file_ondisk(cfg, buf.ptr, 3);
- if (!error && !git_config_find_xdr_r(&buf))
+ if (!error && !git_config_find_xdg_r(&buf))
error = git_config_add_file_ondisk(cfg, buf.ptr, 2);
if (!error && !git_config_find_system_r(&buf))
diff --git a/src/config.h b/src/config.h
index 4e451a2..471b42d 100644
--- a/src/config.h
+++ b/src/config.h
@@ -24,7 +24,7 @@ struct git_config {
};
extern int git_config_find_global_r(git_buf *global_config_path);
-extern int git_config_find_xdr_r(git_buf *system_config_path);
+extern int git_config_find_xdg_r(git_buf *system_config_path);
extern int git_config_find_system_r(git_buf *system_config_path);
extern int git_config_parse_bool(int *out, const char *bool_string);
diff --git a/src/repository.c b/src/repository.c
index d1cf47f..e9c1bdf 100644
--- a/src/repository.c
+++ b/src/repository.c
@@ -445,7 +445,7 @@ static int load_config(
git_config **out,
git_repository *repo,
const char *global_config_path,
- const char *xdr_config_path,
+ const char *xdg_config_path,
const char *system_config_path)
{
git_buf config_path = GIT_BUF_INIT;
@@ -470,8 +470,8 @@ static int load_config(
goto on_error;
}
- if (xdr_config_path != NULL) {
- if (git_config_add_file_ondisk(cfg, xdr_config_path, 2) < 0)
+ if (xdg_config_path != NULL) {
+ if (git_config_add_file_ondisk(cfg, xdg_config_path, 2) < 0)
goto on_error;
}
@@ -493,23 +493,23 @@ on_error:
int git_repository_config__weakptr(git_config **out, git_repository *repo)
{
if (repo->_config == NULL) {
- git_buf global_buf = GIT_BUF_INIT, xdr_buf = GIT_BUF_INIT, system_buf = GIT_BUF_INIT;
+ git_buf global_buf = GIT_BUF_INIT, xdg_buf = GIT_BUF_INIT, system_buf = GIT_BUF_INIT;
int res;
const char *global_config_path = NULL;
- const char *xdr_config_path = NULL;
+ const char *xdg_config_path = NULL;
const char *system_config_path = NULL;
if (git_config_find_global_r(&global_buf) == 0)
global_config_path = global_buf.ptr;
- if (git_config_find_xdr_r(&xdr_buf) == 0)
- xdr_config_path = xdr_buf.ptr;
+ if (git_config_find_xdg_r(&xdg_buf) == 0)
+ xdg_config_path = xdg_buf.ptr;
if (git_config_find_system_r(&system_buf) == 0)
system_config_path = system_buf.ptr;
- res = load_config(&repo->_config, repo, global_config_path, xdr_config_path, system_config_path);
+ res = load_config(&repo->_config, repo, global_config_path, xdg_config_path, system_config_path);
git_buf_free(&global_buf);
git_buf_free(&system_buf);
diff --git a/include/git2/config.h b/include/git2/config.h
index a3202c2..a7d8974 100644
--- a/include/git2/config.h
+++ b/include/git2/config.h
@@ -61,7 +61,7 @@ typedef struct {
* may be used on any `git_config` call to load the
* global configuration file.
*
* This method will not guess the path to the xdr compatible
* config file (.config/git/config).
*
* @param global_config_path Buffer of GIT_PATH_MAX length to store the path
@@ -71,21 +71,21 @@ typedef struct {
GIT_EXTERN(int) git_config_find_global(char *global_config_path, size_t length);
/**
* Locate the path to the global xdr compatible configuration file
*
* The xdr compatible configuration file is usually
* located in `$HOME/.config/git/config`.
*
* This method will try to guess the full path to that
* file, if the file exists. The returned path
* may be used on any `git_config` call to load the
* global configuration file.
*
* @param global_config_path Buffer of GIT_PATH_MAX length to store the path
* @return 0 if a global configuration file has been
* found. Its path will be stored in `buffer`.
*/
-GIT_EXTERN(int) git_config_find_xdr(char *global_config_path, size_t length);
+GIT_EXTERN(int) git_config_find_xdg(char *xdg_config_path, size_t length);
/**
* Locate the path to the system configuration file
@@ -61,7 +61,7 @@ typedef struct {
* global configuration file.
*
- * This method will not guess the path to the xdr compatible
+ * This method will not guess the path to the xdg compatible
* config file (.config/git/config).
*
@@ -71,21 +71,21 @@ typedef struct {
GIT_EXTERN(int) git_config_find_global(char *global_config_path, size_t length);
/**
- * Locate the path to the global xdr compatible configuration file
+ * Locate the path to the global xdg compatible configuration file
*
@@ -71,21 +71,21 @@ typedef struct {
*
- * The xdr compatible configuration file is usually
+ * The xdg compatible configuration file is usually
* located in `$HOME/.config/git/config`.
*
@@ -71,21 +71,21 @@ typedef struct {
* file, if the file exists. The returned path
* may be used on any `git_config` call to load the
- * global configuration file.
+ * xdg compatible configuration file.
*
@@ -71,21 +71,21 @@ typedef struct {
*
- * @param global_config_path Buffer of GIT_PATH_MAX length to store the path
- * @return 0 if a global configuration file has been
+ * @param xdg_config_path Buffer of GIT_PATH_MAX length to store the path
+ * @return 0 if a xdg compatible configuration file has been
* found. Its path will be stored in `buffer`.
*/